@@ -34,6 +34,25 @@ class ReplicationServer(object):
         self.baseurl = url
         self.diff_type = diff_type
 
+    def open_url(self, url):
+        """ Download a resource from the given URL and return a byte sequence
+            of the content.
+
+            This method has no support for cookies or any special authentication
+            methods. If you need these, you have to provide your own custom URL
+            opener. The method has to return an object which supports the
+            `read()` and `readline()` methods to access the content. Example::
+
+                def my_open_url(self, url):
+                    opener = urlrequest.build_opener()
+                    opener.addheaders = [('X-Fancy-Header', 'important_content')]
+                    return opener.open(url)
+
+                svr = ReplicationServer()
+                svr.open_url = my_open_url
+        """
+        return urlrequest.urlopen(url)
+
     def collect_diffs(self, start_id, max_size=1024):
         """ Create a MergeInputReader and download diffs starting with sequence
             id `start_id` into it. `max_size`
@@ -113,7 +132,7 @@ class ReplicationServer(object):
         return diffs.id
 
     def apply_diffs_to_file(self, infile, outfile, start_id, max_size=1024,
-                            set_replication_header=True):
+                            set_replication_header=True, extra_headers={}):
         """ Download diffs starting with sequence id `start_id`, merge them
             with the data from the OSM file named `infile` and write the result
             into a file with the name `outfile`. The output file must not yet
@@ -128,6 +147,9 @@ class ReplicationServer(object):
             will be written into the `writer`. Note that this currently works
             only for the PBF format.
 
+            `extra_headers` is a dict with additional header fields to be set.
+            Most notably, the 'generator' can be set this way.
+
             The function returns a tuple of last downloaded sequence id and
             newest available sequence id if new data has been written or None
             if no data was available or the download failed completely.
@@ -147,6 +169,8 @@ class ReplicationServer(object):
             h.set("osmosis_replication_sequence_number", str(diffs.id))
             info = self.get_state_info(diffs.id)
             h.set("osmosis_replication_timestamp", info.timestamp.strftime("%Y-%m-%dT%H:%M:%SZ"))
+        for k,v in extra_headers.items():
+            h.set(k, v)
 
         writer = oio.Writer(outfile, h)
 
@@ -249,8 +273,9 @@ class ReplicationServer(object):
             returns `None`.
         """
         try:
-            response = urlrequest.urlopen(self.get_state_url(seq))
-        except:
+            response = self.open_url(self.get_state_url(seq))
+        except Exception as err:
+            logging.error(err)
             return None
 
         ts = None
@@ -278,11 +303,11 @@ class ReplicationServer(object):
 
     def get_diff_block(self, seq):
         """ Downloads the diff with the given sequence number and returns
-            it as a byte sequence. Throws a `urllib.error.HTTPError`
-            (or `urllib2.HTTPError` in python2)
+            it as a byte sequence. Throws a :code:`urllib.error.HTTPError`
+            (or :code:`urllib2.HTTPError` in python2)
             if the file cannot be downloaded.
         """
-        return urlrequest.urlopen(self.get_diff_url(seq)).read()
+        return self.open_url(self.get_diff_url(seq)).read()
 
 
     def get_state_url(self, seq):
